@@ -111,37 +111,37 @@ DlgEdFunc::~DlgEdFunc()
 
 //----------------------------------------------------------------------------
 
-BOOL DlgEdFunc::MouseButtonDown( const MouseEvent& )
+sal_Bool DlgEdFunc::MouseButtonDown( const MouseEvent& )
 {
-    return TRUE;
+    return sal_True;
 }
 
 //----------------------------------------------------------------------------
 
-BOOL DlgEdFunc::MouseButtonUp( const MouseEvent& )
+sal_Bool DlgEdFunc::MouseButtonUp( const MouseEvent& )
 {
     aScrollTimer.Stop();
-    return TRUE;
+    return sal_True;
 }
 
 //----------------------------------------------------------------------------
 
-BOOL DlgEdFunc::MouseMove( const MouseEvent& )
+sal_Bool DlgEdFunc::MouseMove( const MouseEvent& )
 {
-    return TRUE;
+    return sal_True;
 }
 
 //----------------------------------------------------------------------------
 
-BOOL DlgEdFunc::KeyInput( const KeyEvent& rKEvt )
+sal_Bool DlgEdFunc::KeyInput( const KeyEvent& rKEvt )
 {
-    BOOL bReturn = FALSE;
+    sal_Bool bReturn = sal_False;
 
     SdrView* pView = pParent->GetView();
     Window* pWindow = pParent->GetWindow();
 
     KeyCode aCode = rKEvt.GetKeyCode();
-    USHORT nCode = aCode.GetCode();
+    sal_uInt16 nCode = aCode.GetCode();
 
     switch ( nCode )
     {
@@ -150,7 +150,7 @@ BOOL DlgEdFunc::KeyInput( const KeyEvent& rKEvt )
             if ( pView->IsAction() )
             {
                 pView->BrkAction();
-                bReturn = TRUE;
+                bReturn = sal_True;
             }
             else if ( pView->AreObjectsMarked() )
             {
@@ -161,7 +161,7 @@ BOOL DlgEdFunc::KeyInput( const KeyEvent& rKEvt )
                 else
                     pView->UnmarkAll();
                 
-                bReturn = TRUE;
+                bReturn = sal_True;
             }
         }
         break;
@@ -180,7 +180,7 @@ BOOL DlgEdFunc::KeyInput( const KeyEvent& rKEvt )
                 if ( pView->AreObjectsMarked() )
                     pView->MakeVisible( pView->GetAllMarkedRect(), *pWindow );
 
-                bReturn = TRUE;
+                bReturn = sal_True;
             }
             else if ( aCode.IsMod1() )
             {
@@ -197,7 +197,7 @@ BOOL DlgEdFunc::KeyInput( const KeyEvent& rKEvt )
                     pView->MakeVisible( aVisRect, *pWindow );
                 }
 
-                bReturn = TRUE;
+                bReturn = sal_True;
             }
         }
         break;
@@ -304,13 +304,13 @@ BOOL DlgEdFunc::KeyInput( const KeyEvent& rKEvt )
                         if ( pView->IsDragObj() )
                         {
                             bool bWasNoSnap = rDragStat.IsNoSnap();
-                            BOOL bWasSnapEnabled = pView->IsSnapEnabled();
+                            sal_Bool bWasSnapEnabled = pView->IsSnapEnabled();
 
                             // switch snapping off
                             if ( !bWasNoSnap )
-                                ((SdrDragStat&)rDragStat).SetNoSnap( TRUE );
+                                ((SdrDragStat&)rDragStat).SetNoSnap( sal_True );
                             if ( bWasSnapEnabled )
-                                pView->SetSnapEnabled( FALSE );
+                                pView->SetSnapEnabled( sal_False );
 
                             pView->MovAction( aEndPoint );
                             pView->EndDragObj();
@@ -346,7 +346,7 @@ BOOL DlgEdFunc::KeyInput( const KeyEvent& rKEvt )
                 }
             }
 
-            bReturn = TRUE;
+            bReturn = sal_True;
         }
         break;
         default:
@@ -366,30 +366,30 @@ BOOL DlgEdFunc::KeyInput( const KeyEvent& rKEvt )
 DlgEdFuncInsert::DlgEdFuncInsert( DlgEditor* pParent_ ) :
     DlgEdFunc( pParent_ )
 {
-    pParent_->GetView()->SetCreateMode( TRUE );
+    pParent_->GetView()->SetCreateMode( sal_True );
 }
 
 //----------------------------------------------------------------------------
 
 DlgEdFuncInsert::~DlgEdFuncInsert()
 {
-    pParent->GetView()->SetEditMode( TRUE );
+    pParent->GetView()->SetEditMode( sal_True );
 }
 
 //----------------------------------------------------------------------------
 
-BOOL DlgEdFuncInsert::MouseButtonDown( const MouseEvent& rMEvt )
+sal_Bool DlgEdFuncInsert::MouseButtonDown( const MouseEvent& rMEvt )
 {
     if( !rMEvt.IsLeft() )
-        return TRUE;
+        return sal_True;
 
     SdrView* pView  = pParent->GetView();
     Window*  pWindow= pParent->GetWindow();
     pView->SetActualWin( pWindow );
 
     Point aPos = pWindow->PixelToLogic( rMEvt.GetPosPixel() );
-    USHORT nHitLog = USHORT ( pWindow->PixelToLogic(Size(3,0)).Width() );
-    USHORT nDrgLog = USHORT ( pWindow->PixelToLogic(Size(3,0)).Width() );
+    sal_uInt16 nHitLog = sal_uInt16 ( pWindow->PixelToLogic(Size(3,0)).Width() );
+    sal_uInt16 nDrgLog = sal_uInt16 ( pWindow->PixelToLogic(Size(3,0)).Width() );
 
     pWindow->CaptureMouse();
 
@@ -414,12 +414,12 @@ BOOL DlgEdFuncInsert::MouseButtonDown( const MouseEvent& rMEvt )
             pParent->ShowProperties();
     }
 
-    return TRUE;	
+    return sal_True;	
 }
 
 //----------------------------------------------------------------------------
 
-BOOL DlgEdFuncInsert::MouseButtonUp( const MouseEvent& rMEvt )
+sal_Bool DlgEdFuncInsert::MouseButtonUp( const MouseEvent& rMEvt )
 {
     DlgEdFunc::MouseButtonUp( rMEvt );
 
@@ -436,34 +436,34 @@ BOOL DlgEdFuncInsert::MouseButtonUp( const MouseEvent& rMEvt )
 
         if ( !pView->AreObjectsMarked() )
         {
-            USHORT nHitLog = USHORT ( pWindow->PixelToLogic(Size(3,0)).Width() );
+            sal_uInt16 nHitLog = sal_uInt16 ( pWindow->PixelToLogic(Size(3,0)).Width() );
             Point aPos( pWindow->PixelToLogic( rMEvt.GetPosPixel() ) );
             pView->MarkObj(aPos, nHitLog);
         }
 
         if( pView->AreObjectsMarked() )
-            return TRUE;
+            return sal_True;
         else
-            return FALSE;
+            return sal_False;
     }
     else
     {
         if ( pView->IsDragObj() )
              pView->EndDragObj( rMEvt.IsMod1() );
-        return TRUE;
+        return sal_True;
     }	
 }
 
 //----------------------------------------------------------------------------
 
-BOOL DlgEdFuncInsert::MouseMove( const MouseEvent& rMEvt )
+sal_Bool DlgEdFuncInsert::MouseMove( const MouseEvent& rMEvt )
 {
     SdrView* pView  = pParent->GetView();
     Window*  pWindow= pParent->GetWindow();
     pView->SetActualWin( pWindow );
 
     Point	aPos( pWindow->PixelToLogic( rMEvt.GetPosPixel() ) );
-    USHORT nHitLog = USHORT ( pWindow->PixelToLogic(Size(3,0)).Width() );
+    sal_uInt16 nHitLog = sal_uInt16 ( pWindow->PixelToLogic(Size(3,0)).Width() );
 
     if ( pView->IsAction() )
     {
@@ -473,14 +473,14 @@ BOOL DlgEdFuncInsert::MouseMove( const MouseEvent& rMEvt )
 
     pWindow->SetPointer( pView->GetPreferedPointer( aPos, pWindow, nHitLog ) );
 
-    return TRUE;
+    return sal_True;
 }
 
 //----------------------------------------------------------------------------
 
 DlgEdFuncSelect::DlgEdFuncSelect( DlgEditor* pParent_ ) :
     DlgEdFunc( pParent_ ),
-    bMarkAction(FALSE)
+    bMarkAction(sal_False)
 {
 }
 
@@ -492,15 +492,15 @@ DlgEdFuncSelect::~DlgEdFuncSelect()
 
 //----------------------------------------------------------------------------
 
-BOOL DlgEdFuncSelect::MouseButtonDown( const MouseEvent& rMEvt )
+sal_Bool DlgEdFuncSelect::MouseButtonDown( const MouseEvent& rMEvt )
 {
     // get view from parent
     SdrView* pView   = pParent->GetView();
     Window*  pWindow = pParent->GetWindow();
     pView->SetActualWin( pWindow );
 
-    USHORT nDrgLog = USHORT ( pWindow->PixelToLogic(Size(3,0)).Width() );
-    USHORT nHitLog = USHORT ( pWindow->PixelToLogic(Size(3,0)).Width() );
+    sal_uInt16 nDrgLog = sal_uInt16 ( pWindow->PixelToLogic(Size(3,0)).Width() );
+    sal_uInt16 nHitLog = sal_uInt16 ( pWindow->PixelToLogic(Size(3,0)).Width() );
     Point  aMDPos = pWindow->PixelToLogic( rMEvt.GetPosPixel() );
 
     if ( rMEvt.IsLeft() && rMEvt.GetClicks() == 1 )
@@ -540,7 +540,7 @@ BOOL DlgEdFuncSelect::MouseButtonDown( const MouseEvent& rMEvt )
             {
                 // select object
                 pView->BegMarkObj(aMDPos);
-                bMarkAction = TRUE;
+                bMarkAction = sal_True;
             }
         }
     }
@@ -551,12 +551,12 @@ BOOL DlgEdFuncSelect::MouseButtonDown( const MouseEvent& rMEvt )
             pParent->ShowProperties();
     }
 
-    return TRUE;
+    return sal_True;
 }
 
 //----------------------------------------------------------------------------
 
-BOOL DlgEdFuncSelect::MouseButtonUp( const MouseEvent& rMEvt )
+sal_Bool DlgEdFuncSelect::MouseButtonUp( const MouseEvent& rMEvt )
 {
     DlgEdFunc::MouseButtonUp( rMEvt );
 
@@ -566,7 +566,7 @@ BOOL DlgEdFuncSelect::MouseButtonUp( const MouseEvent& rMEvt )
     pView->SetActualWin( pWindow );
 
     Point aPnt( pWindow->PixelToLogic( rMEvt.GetPosPixel() ) );
-    USHORT nHitLog = USHORT ( pWindow->PixelToLogic(Size(3,0)).Width() );
+    sal_uInt16 nHitLog = sal_uInt16 ( pWindow->PixelToLogic(Size(3,0)).Width() );
 
     if ( rMEvt.IsLeft() )
     {
@@ -580,46 +580,27 @@ BOOL DlgEdFuncSelect::MouseButtonUp( const MouseEvent& rMEvt )
         if (pView->IsAction() )
         {
             pView->EndAction();
-            //if( bMarkAction )
-                //pParent->UnmarkDialog();
         }
     }
 
-//	USHORT nClicks = rMEvt.GetClicks();
-//	if (nClicks == 2)
-//	{
-//		if ( pView->AreObjectsMarked() )
-//		{
-//			const SdrMarkList& rMarkList = pView->GetMarkedObjectList();
-//
-//			if (rMarkList.GetMarkCount() == 1)
-//			{
-//				SdrMark* pMark = rMarkList.GetMark(0);
-//				SdrObject* pObj = pMark->GetMarkedSdrObj();
-//
-//				// edit objects here
-//			}
-//		}
-//	}
-
-    bMarkAction = FALSE;
+    bMarkAction = sal_False;
 
     pWindow->SetPointer( pView->GetPreferedPointer( aPnt, pWindow, nHitLog ) );
     pWindow->ReleaseMouse();
 
-    return TRUE;
+    return sal_True;
 }
 
 //----------------------------------------------------------------------------
 
-BOOL DlgEdFuncSelect::MouseMove( const MouseEvent& rMEvt )
+sal_Bool DlgEdFuncSelect::MouseMove( const MouseEvent& rMEvt )
 {
     SdrView* pView  = pParent->GetView();
     Window*  pWindow= pParent->GetWindow();
     pView->SetActualWin( pWindow );
 
     Point aPnt( pWindow->PixelToLogic( rMEvt.GetPosPixel() ) );
-    USHORT nHitLog = USHORT ( pWindow->PixelToLogic(Size(3,0)).Width() );
+    sal_uInt16 nHitLog = sal_uInt16 ( pWindow->PixelToLogic(Size(3,0)).Width() );
 
     if ( pView->IsAction() )
     {
@@ -632,7 +613,7 @@ BOOL DlgEdFuncSelect::MouseMove( const MouseEvent& rMEvt )
 
     pWindow->SetPointer( pView->GetPreferedPointer( aPnt, pWindow, nHitLog ) );
 
-    return TRUE;
+    return sal_True;
 }
 
 //----------------------------------------------------------------------------
