@@ -76,9 +76,6 @@ bool SignatureCreatorImpl::checkReady() const
  *   RESULT
  *	bReady - true if all conditions are satisfied, false otherwise
  *
- *   HISTORY
- *	05.01.2004 -	implemented
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
@@ -109,9 +106,6 @@ void SignatureCreatorImpl::notifyResultListener() const
  *   RESULT
  *	empty
  *
- *   HISTORY
- *	05.01.2004 -	implemented
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
@@ -147,9 +141,6 @@ void SignatureCreatorImpl::startEngine(	const cssu::Reference<
  *   RESULT
  *	empty
  *
- *   HISTORY
- *	05.01.2004 -	implemented
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
@@ -193,9 +184,6 @@ void SignatureCreatorImpl::clearUp() const
  *   RESULT
  *	empty
  *
- *   HISTORY
- *	05.01.2004 -	implemented
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
